function [f_of_X,K] = data_generator_multi(n,p,d,alpha,z,m,seed)

% Creates the observations and the functions for the basic multi-task algorithm, as described in the
% simulations of the article.
%
% [f_of_X,K] = kernel_article(n,d,alpha,z,m,seed)
%
% Input
% n : number of observations
% p : number of tasks
% d : dimension of the data space
% alpha : matrix used to determine the f^j. size m*p
%   If the functions f^j are to be equal, then alpha has to be of the form [alpha_1,...,alpha_1], with alpha_1 of size m*1.
% z :  matrix used to determine the f^j. size mp*d. 
%   If the functions f^j are to be equal, then z has to be of the form [z_1;...;z_1], with z_1 of size m*d.
% m : size of the linear combination of functions of the RKHS used to generate the f^j
% seed : integer, used to initiate the pseudo-random generator.
%
% Output
% f_of_X : matrix of f^j(X_i). Row : observations, columns : tasks. size n*p
% K : kernel matrix. size n*n


warning off;
rand('state',seed);
randn('state',seed);
warning on;

% Data generation

X = randn(n,d);
a = zeros(m*p,p);
for k = 1:p
    a((k-1)*m+1:k*m,k) = alpha(:,k);
end    

T = zeros(n*p,p*m);
for i = 1:n
    for k = 1:p
        for j = 1:m
            T(n*(k-1)+i,(k-1)*m+j) =  prod(exp(-abs(X(i,:)-z(m*(k-1)+j,:))));
        end
    end
end

fX = sum(T*a,2);
f_of_X = compact(fX,n,p);

K = zeros(n,n);
for i = 1:n
    K(i,i) = 1;
    for j = i+1:n
        K(i,j) = prod(exp( -( abs( X(i,:)-X(j,:) ) ) ) );
        K(j,i) = K(i,j);
    end
end    
end